*********************************
Documentation for the python code
*********************************

The original modules of ttcrpy are cgrid2d, cgrid3d, cmesh2d and cmesh3d.  These
modules are deprecated in favor of rgrid and an upcoming tmesh modules.

.. toctree::
   :maxdepth: 2
   :caption: Modules:

   code_rgrid.rst
   code_cgrid2d.rst
   code_cgrid3d.rst
   code_cmesh2d.rst
   code_cmesh3d.rst
